.. _release_history:

Release and Version History
==============================================================================


Backlog (TODO)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
**Features and Improvements**

**Minor Improvements**

**Bugfixes**

**Miscellaneous**


0.2.1 (2023-03-08)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
**Features and Improvements**

- add ``Node.iter_org_units`` and ``Node_iter_accounts`` methods.
- add ``OrgStructure`` class to represent the organization structure tree.
- drop ``get_org_structure``, add ``OrgStructure.get_org_structure`` method.
- add ``OrgStructure.visualize`` method.
- add ``OrgStructure.to_csv`` method.
- add ``OrgStructure.is_x_in_y`` method.


0.1.1 (2023-03-06)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
**Features and Improvements**

- First release
- add data model for ``Organization``, ``OrganizationUnit``, ``Account``
- add ``get_org_structure`` method to get the organization structure tree.
